@@ -2,124 +2,20 @@
 if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
 
 #' @title Cross-validate regression models for model selection
-#' @description Cross-validate one or multiple gaussian or binomial
+#' @description
+#'  \Sexpr[results=rd, stage=render]{lifecycle::badge("stable")}
+#'
+#'  Cross-validate one or multiple gaussian or binomial
 #'  models at once. Perform repeated cross-validation.
 #'  Returns results in a tibble for easy comparison,
 #'  reporting and further analysis.
-#' @details
-#'
-#'  Packages used:
-#'
-#'  \subsection{Models}{
-#'
-#'  Gaussian: \link[stats:lm]{stats::lm}, \code{\link[lme4:lmer]{lme4::lmer}}
-#'
-#'  Binomial: \code{\link[stats:glm]{stats::glm}}, \code{\link[lme4:glmer]{lme4::glmer}}
-#'  }
-#'  \subsection{Results}{
-#'  \subsection{Gaussian}{
-#'
-#'  r2m : \code{\link[MuMIn:r.squaredGLMM]{MuMIn::r.squaredGLMM}}
-#'
-#'  r2c : \code{\link[MuMIn:r.squaredGLMM]{MuMIn::r.squaredGLMM}}
-#'
-#'  AIC : \code{\link[stats:AIC]{stats::AIC}}
-#'
-#'  AICc : \code{\link[AICcmodavg:AICc]{AICcmodavg::AICc}}
-#'
-#'  BIC : \code{\link[stats:BIC]{stats::BIC}}
-#'
-#'  }
-#'  \subsection{Binomial}{
-#'
-#'  Confusion matrix: \code{\link[caret:confusionMatrix]{caret::confusionMatrix}}
-#'
-#'  ROC: \code{\link[pROC:roc]{pROC::roc}}
-#'
-#'  MCC: \code{\link[mltools:mcc]{mltools::mcc}}
-#'  }
-#'  }
-#' @return
-#'  Tbl (tibble) with results for each model.
-#'
-#'  \subsection{Shared across families}{
-#'  A nested tibble with \strong{coefficients} of the models from all iterations.
-#'
-#'  Number of \emph{total} \strong{folds}.
-#'
-#'  Number of \strong{fold columns}.
-#'
-#'  Count of \strong{convergence warnings}. Consider discarding models that did not converge on all
-#'  iterations. Note: you might still see results, but these should be taken with a grain of salt!
-#'
-#'  Count of \strong{Singular Fit messages}. See \code{?\link[lme4:isSingular]{lme4::isSingular}} for more information.
-#'
-#'  Specified \strong{family}.
-#'
-#'  Specified \strong{link} function.
-#'
-#'  Name of \strong{dependent} variable.
-#'
-#'  Names of \strong{fixed} effects.
-#'
-#'  Names of \strong{random} effects, if any.
-#'  }
-#'
-#'  \subsection{Gaussian Results}{
-#'  Average \strong{RMSE}, \strong{MAE}, \strong{r2m}, \strong{r2c}, \strong{AIC}, \strong{AICc},
-#'  and \strong{BIC} of all the iterations*,
-#'  \emph{\strong{omitting potential NAs} from non-converged iterations}.
-#'  Note that the Information Criteria metrics (AIC, AICc, and BIC) are also averages.
-#'
-#'  A nested tibble with the \strong{predictions} and targets.
-#'
-#'  A nested tibble with the non-averaged \strong{results} from all iterations.
-#'
-#'  * In \emph{repeated cross-validation},
-#'  the metrics are first averaged for each fold column (repetition) and then averaged again.
-#'
-#'  }
-#'
-#'  \subsection{Binomial Results}{
-#'  Based on the collected predictions from the test folds*,
-#'  a confusion matrix and a ROC curve are created to get the following:
-#'
-#'  Confusion Matrix:
-#'
-#'  \strong{Balanced Accuracy}, \strong{F1},
-#'  \strong{Sensitivity}, \strong{Specificity},
-#'  \strong{Positive Prediction Value},
-#'  \strong{Negative Prediction Value},
-#'  \strong{Kappa},
-#'  \strong{Detection Rate},
-#'  \strong{Detection Prevalence},
-#'  \strong{Prevalence}, and
-#'  \strong{MCC} (Matthews correlation coefficient).
-#'
-#'  ROC:
-#'
-#'  \strong{AUC}, \strong{Lower CI}, and \strong{Upper CI}
-#'
-#'  A nested tibble with \strong{predictions}, predicted classes (depends on \code{cutoff}), and the targets.
-#'  Note, that the \strong{predictions are not necessarily of the specified \code{positive} class}, but of
-#'  the model's positive class (second level of dependent variable, alphabetically).
-#'
-#'  A nested tibble with the sensativities and specificities from the \strong{ROC} curve(s).
-#'
-#'  A nested tibble with the \strong{confusion matrix}/matrices.
-#'  The \code{Pos_} columns tells you whether a row is a
-#'  True Positive (TP), True Negative (TN), False Positive (FP), or False Negative (FN),
-#'  depending on which level is the "positive" class. I.e. the level you wish to predict.
-#'
-#'  A nested tibble with the \strong{results} from all fold columns, if using repeated cross-validation.
-#'
-#'  * In \emph{repeated cross-validation}, an evaluation is made per fold column (repetition) and averaged.
-#'
-#'  }
 #'
+#'  See \code{\link[cvms:cross_validate_fn]{cross_validate_fn()}} for use
+#'  with custom model functions.
 #' @author Ludvig Renbo Olsen, \email{r-pkgs@@ludvigolsen.dk}
 #' @author Benjamin Hugh Zachariae
 #' @export
+#' @family validation functions
 #' @param data Data frame.
 #'
 #'  Must include grouping factor for identifying folds
@@ -170,12 +66,151 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
 #'  N.B. Only affects evaluation metrics, not the model training or returned predictions.
 #'
 #'  N.B. \strong{Binomial models only}.
+#' @param metrics List for enabling/disabling metrics.
+#'
+#'   E.g. \code{list("RMSE" = FALSE)} would remove RMSE from the results,
+#'   and \code{list("Accuracy" = TRUE)} would add the regular accuracy metric
+#'   to the classification results.
+#'   Default values (TRUE/FALSE) will be used for the remaining metrics available.
+#'
+#'   Also accepts the string \code{"all"}.
+#'
+#'   N.B. Currently, disabled metrics are still computed.
 #' @param rm_nc Remove non-converged models from output. (Logical)
 #' @param model_verbose Message name of used model function on each iteration. (Logical)
 #' @param parallel Whether to cross-validate the list of models in parallel. (Logical)
 #'
 #'  Remember to register a parallel backend first.
 #'  E.g. with \code{doParallel::registerDoParallel}.
+#' @details
+#'
+#'  Packages used:
+#'
+#'  \subsection{Models}{
+#'
+#'  Gaussian: \link[stats:lm]{stats::lm}, \code{\link[lme4:lmer]{lme4::lmer}}
+#'
+#'  Binomial: \code{\link[stats:glm]{stats::glm}}, \code{\link[lme4:glmer]{lme4::glmer}}
+#'  }
+#'  \subsection{Results}{
+#'  \subsection{Gaussian}{
+#'
+#'  r2m : \code{\link[MuMIn:r.squaredGLMM]{MuMIn::r.squaredGLMM}}
+#'
+#'  r2c : \code{\link[MuMIn:r.squaredGLMM]{MuMIn::r.squaredGLMM}}
+#'
+#'  AIC : \code{\link[stats:AIC]{stats::AIC}}
+#'
+#'  AICc : \code{\link[MuMIn:AICc]{MuMIn::AICc}}
+#'
+#'  BIC : \code{\link[stats:BIC]{stats::BIC}}
+#'
+#'  }
+#'  \subsection{Binomial}{
+#'
+#'  Confusion matrix: \code{\link[caret:confusionMatrix]{caret::confusionMatrix}}
+#'
+#'  ROC: \code{\link[pROC:roc]{pROC::roc}}
+#'
+#'  MCC: \code{\link[mltools:mcc]{mltools::mcc}}
+#'  }
+#'  }
+#' @return
+#'  Tbl (tibble) with results for each model.
+#'
+#'  \subsection{Shared across families}{
+#'  A nested tibble with \strong{coefficients} of the models from all iterations.
+#'
+#'  Number of \emph{total} \strong{folds}.
+#'
+#'  Number of \strong{fold columns}.
+#'
+#'  Count of \strong{convergence warnings}. Consider discarding models that did not converge on all
+#'  iterations. Note: you might still see results, but these should be taken with a grain of salt!
+#'
+#'  Count of \strong{other warnings}. These are warnings without keywords such as "convergence".
+#'
+#'  Count of \strong{Singular Fit messages}. See \code{?\link[lme4:isSingular]{lme4::isSingular}} for more information.
+#'
+#'  Nested tibble with the \strong{warnings and messages} caught for each model.
+#'
+#'  Specified \strong{family}.
+#'
+#'  Specified \strong{link} function.
+#'
+#'  Name of \strong{dependent} variable.
+#'
+#'  Names of \strong{fixed} effects.
+#'
+#'  Names of \strong{random} effects, if any.
+#'  }
+#'
+#'  ----------------------------------------------------------------
+#'
+#'  \subsection{Gaussian Results}{
+#'
+#'  ----------------------------------------------------------------
+#'
+#'  Average \strong{RMSE}, \strong{MAE}, \strong{r2m}, \strong{r2c}, \strong{AIC}, \strong{AICc},
+#'  and \strong{BIC} of all the iterations*,
+#'  \emph{\strong{omitting potential NAs} from non-converged iterations}.
+#'  Note that the Information Criteria metrics (AIC, AICc, and BIC) are also averages.
+#'
+#'  A nested tibble with the \strong{predictions} and targets.
+#'
+#'  A nested tibble with the non-averaged \strong{results} from all iterations.
+#'
+#'  * In \emph{repeated cross-validation},
+#'  the metrics are first averaged for each fold column (repetition) and then averaged again.
+#'
+#'  }
+#'
+#'  ----------------------------------------------------------------
+#'
+#'  \subsection{Binomial Results}{
+#'
+#'  ----------------------------------------------------------------
+#'
+#'  Based on the \strong{collected} predictions from the test folds*,
+#'  a confusion matrix and a ROC curve are created to get the following:
+#'
+#'  ROC:
+#'
+#'  \strong{AUC}, \strong{Lower CI}, and \strong{Upper CI}
+#'
+#'  Confusion Matrix:
+#'
+#'  \strong{Balanced Accuracy}, \strong{F1},
+#'  \strong{Sensitivity}, \strong{Specificity},
+#'  \strong{Positive Prediction Value},
+#'  \strong{Negative Prediction Value},
+#'  \strong{Kappa},
+#'  \strong{Detection Rate},
+#'  \strong{Detection Prevalence},
+#'  \strong{Prevalence}, and
+#'  \strong{MCC} (Matthews correlation coefficient).
+#'
+#'  Other available metrics (disabled by default, see \code{metrics}):
+#'  \strong{Accuracy}.
+#'
+#'  Also includes:
+#'
+#'  A nested tibble with \strong{predictions}, predicted classes (depends on \code{cutoff}), and the targets.
+#'  Note, that the \strong{predictions are not necessarily of the specified \code{positive} class}, but of
+#'  the model's positive class (second level of dependent variable, alphabetically).
+#'
+#'  A nested tibble with the sensativities and specificities from the \strong{ROC} curve(s).
+#'
+#'  A nested tibble with the \strong{confusion matrix}/matrices.
+#'  The \code{Pos_} columns tells you whether a row is a
+#'  True Positive (TP), True Negative (TN), False Positive (FP), or False Negative (FN),
+#'  depending on which level is the "positive" class. I.e. the level you wish to predict.
+#'
+#'  A nested tibble with the \strong{results} from all fold columns, when using \emph{repeated cross-validation}.
+#'
+#'  * In \emph{repeated cross-validation}, an evaluation is made per fold column (repetition) and averaged.
+#'
+#'  }
 #' @examples
 #' # Attach packages
 #' library(cvms)
@@ -190,8 +225,8 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
 #'
 #' # Fold data
 #' data <- fold(data, k = 4,
-#'           cat_col = 'diagnosis',
-#'           id_col = 'participant') %>%
+#'              cat_col = 'diagnosis',
+#'              id_col = 'participant') %>%
 #'         arrange(.folds)
 #'
 #' # Cross-validate a single model
@@ -200,7 +235,7 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
 #' # Gaussian
 #' cross_validate(data,
 #'                models = "score~diagnosis",
-#'                family='gaussian',
+#'                family = 'gaussian',
 #'                REML = FALSE)
 #'
 #' # Binomial
@@ -215,7 +250,7 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
 #'
 #' cross_validate(data,
 #'                models = models,
-#'                family='gaussian',
+#'                family = 'gaussian',
 #'                REML = FALSE)
 #'
 #' # Use non-default link functions
@@ -255,25 +290,24 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
 #' @importFrom rlang .data
 cross_validate <- function(data, models, fold_cols = '.folds', family = 'gaussian',
                            link = NULL, control = NULL, REML = FALSE,
-                           cutoff = 0.5, positive = 2, rm_nc = FALSE,
+                           cutoff = 0.5, positive = 2,
+                           metrics = list(), rm_nc = FALSE,
                            parallel = FALSE, model_verbose = FALSE){
 
 
   return(basics_cross_validate_list(data = data,
-                                   model_list = models,
-                                   fold_cols = fold_cols,
-                                   family = family,
-                                   link = link,
-                                   control=control,
-                                   REML = REML,
-                                   cutoff = cutoff,
-                                   positive = positive,
-                                   rm_nc = rm_nc,
-                                   model_verbose = model_verbose,
-                                   parallel_ = parallel,
-                                   parallelize = "models"))
-
-
-
+                                    model_list = models,
+                                    fold_cols = fold_cols,
+                                    family = family,
+                                    link = link,
+                                    control = control,
+                                    REML = REML,
+                                    cutoff = cutoff,
+                                    positive = positive,
+                                    metrics = metrics,
+                                    rm_nc = rm_nc,
+                                    model_verbose = model_verbose,
+                                    parallel_ = parallel,
+                                    parallelize = "models"))
 }
 
